@@ -23,7 +23,6 @@
 #include <glib/gi18n.h>
 #include <gdk/gdk.h>
 
-#include "gnome-settings-plugin.h"
 #include "gnome-settings-profile.h"
 #include "gsd-color-calibrate.h"
 #include "gsd-color-manager.h"
@@ -85,7 +84,10 @@ out:
 void
 gsd_color_manager_stop (GsdColorManager *manager)
 {
+        GsdColorManagerPrivate *priv = manager->priv;
         g_debug ("Stopping color manager");
+        gsd_color_state_stop (priv->state);
+        gsd_color_profiles_stop (priv->profiles);
 }
 
 static void
