@@ -23,7 +23,6 @@
 #include <glib.h>
 #include <gio/gio.h>
 
-#include "gnome-settings-plugin.h"
 #include "gnome-settings-profile.h"
 #include "gnome-settings-bus.h"
 #include "gsd-smartcard-manager.h"
@@ -54,7 +53,7 @@ struct GsdSmartcardManagerPrivate
 
         GSettings *settings;
 
-        NSSInitContext *nss_context;
+        guint32 nss_is_loaded : 1;
 };
 
 #define CONF_SCHEMA "org.gnome.settings-daemon.peripherals.smartcard"
@@ -93,14 +92,7 @@ static void
 load_nss (GsdSmartcardManager *self)
 {
         GsdSmartcardManagerPrivate *priv = self->priv;
-        NSSInitContext *context = NULL;
-
-        /* The first field in the NSSInitParameters structure
-         * is the size of the structure. NSS requires this, so
-         * that it can change the size of the structure in future
-         * versions of NSS in a detectable way
-         */
-        NSSInitParameters parameters = { sizeof (parameters), };
+        SECStatus status = SECSuccess;
         static const guint32 flags = NSS_INIT_READONLY
                                    | NSS_INIT_FORCEOPEN
                                    | NSS_INIT_NOROOTINIT
@@ -112,10 +104,10 @@ load_nss (GsdSmartcardManager *self)
 
         PR_Init (PR_USER_THREAD, PR_PRIORITY_NORMAL, 0);
 
-        context = NSS_InitContext (GSD_SMARTCARD_MANAGER_NSS_DB,
-                                   "", "", SECMOD_DB, &parameters, flags);
+        status = NSS_Initialize (GSD_SMARTCARD_MANAGER_NSS_DB,
+                                 "", "", SECMOD_DB, flags);
 
-        if (context == NULL) {
+        if (status != SECSuccess) {
                 gsize error_message_size;
                 char *error_message;
 
@@ -130,14 +122,13 @@ load_nss (GsdSmartcardManager *self)
                         g_debug ("NSS security system could not be initialized - %s",
                                  error_message);
                 }
-
-                priv->nss_context = NULL;
+                priv->nss_is_loaded = FALSE;
                 return;
 
         }
 
         g_debug ("NSS database '%s' loaded", GSD_SMARTCARD_MANAGER_NSS_DB);
-        priv->nss_context = context;
+        priv->nss_is_loaded = TRUE;
 }
 
 static void
@@ -146,9 +137,9 @@ unload_nss (GsdSmartcardManager *self)
         g_debug ("attempting to unload NSS security system with database '%s'",
                  GSD_SMARTCARD_MANAGER_NSS_DB);
 
-        if (self->priv->nss_context != NULL) {
-                g_clear_pointer (&self->priv->nss_context,
-                                 NSS_ShutdownContext);
+        if (self->priv->nss_is_loaded) {
+                NSS_Shutdown ();
+                self->priv->nss_is_loaded = FALSE;
                 g_debug ("NSS database '%s' unloaded", GSD_SMARTCARD_MANAGER_NSS_DB);
         } else {
                 g_debug ("NSS database '%s' already not loaded", GSD_SMARTCARD_MANAGER_NSS_DB);
